@@ -1,9 +1,9 @@
 from __future__ import absolute_import, division, print_function, unicode_literals
 
+import json
 import logging
 import socket
 
-from smarkets.compatibility import json
 
 log = logging.getLogger(__name__)
 
